@@ -213,8 +213,8 @@ mempager(s), root()
 
 	keynode *env;
 	
-	static char *vars[] = {"HOME", "USER", "IDENT", "PATH", "LANG", "PWD", "TZ", "TMP", "SHELL", "CFG", NULL};
-	char **varp = vars;
+	static const char *vars[] = {"HOME", "USER", "IDENT", "PATH", "LANG", "PWD", "TZ", "TMP", "SHELL", "CFG", NULL};
+	const char **varp = vars;
 	const char *cp;
 
 	root.setId((char *)name);
