@@ -201,6 +201,7 @@ class __LOCAL stack : private service::callback, private mapped_reuse<MappedCall
 {
 private:
 	friend class thread;
+	friend class messages;
 
 	class call;
 
@@ -348,6 +349,8 @@ private:
 	const char *volatile proxy;
 	const char *iface;
 	const char *agent;
+	const char *system;
+	const char *anon;
 	short port;
 	bool incoming, outgoing, dumping;
 	int send101;
@@ -369,6 +372,7 @@ public:
 	__EXPORT static void clear(session *s);
 	__EXPORT static void close(session *s);
 	__EXPORT static session *access(int cid);
+	__EXPORT static char *sipHostid(const char *uri, char *buf, size_t size);
 	__EXPORT static char *sipUserid(const char *uri, char *buf, size_t size);
 	__EXPORT static char *sipAddress(struct sockaddr_internet *addr, char *buf, const char *user = NULL, size_t size = MAX_URI_SIZE);
 	__EXPORT static char *sipPublish(struct sockaddr_internet *addr, char *buf, const char *user = NULL, size_t size = MAX_URI_SIZE);
@@ -468,6 +472,7 @@ public:
 	static void automatic(void);
 	static void update(const char *userid);
 	static bool publish(const char *to, const char *reply, const char *from, caddr_t body, size_t size, const char *msgtype);
+	static bool system(const char *to, const char *message);
 };
 
 
@@ -489,6 +494,7 @@ private:
 	char identity[MAX_USERID_SIZE];
 	char dialing[MAX_USERID_SIZE];
 	char display[MAX_DISPLAY_SIZE];
+	char requesting[MAX_URI_SIZE];
 	struct sockaddr_internet iface;
 	Socket::address via_address, from_address, request_address;
 	stack::session *session;
@@ -508,6 +514,7 @@ private:
 
 	void send_reply(int error);
 	void expiration(void);
+	void inviteRemote(stack::session *session, const char *uri);
 	void inviteLocal(stack::session *session, registry::mapped *rr);
 	void invite(void);
 	void identify(void);
